==> haskell-persistent-2.8.2-84-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent
version: 2.8.2
id: persistent-2.8.2-6LIvnMKOruG8xrkPMxIJk6
key: persistent-2.8.2-6LIvnMKOruG8xrkPMxIJk6
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.
category: Database, Yesod
abi: 58f9b3adaf7d19049256be69172f92fc
exposed: True
exposed-modules:
    Database.Persist Database.Persist.Class Database.Persist.Quasi
    Database.Persist.Sql Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.Types
hidden-modules: Database.Persist.Types.Base
                Database.Persist.Class.DeleteCascade
                Database.Persist.Class.PersistEntity
                Database.Persist.Class.PersistQuery
                Database.Persist.Class.PersistUnique
                Database.Persist.Class.PersistConfig
                Database.Persist.Class.PersistField
                Database.Persist.Class.PersistStore Database.Persist.Sql.Migration
                Database.Persist.Sql.Internal Database.Persist.Sql.Types
                Database.Persist.Sql.Raw Database.Persist.Sql.Raw.QQ
                Database.Persist.Sql.Run Database.Persist.Sql.Class
                Database.Persist.Sql.Orphan.PersistQuery
                Database.Persist.Sql.Orphan.PersistStore
                Database.Persist.Sql.Orphan.PersistUnique
import-dirs: /usr/lib/ghc-8.4.3/site-local/persistent-2.8.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/persistent-2.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/persistent-2.8.2
hs-libraries: HSpersistent-2.8.2-6LIvnMKOruG8xrkPMxIJk6
depends:
    base-4.11.1.0 bytestring-0.10.8.2 transformers-0.5.5.0 time-1.8.0.2
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh text-1.2.3.0
    containers-0.5.11.0 conduit-1.3.0.3-6EkWr2AN7teFYGMPRMc0XT
    resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q
    resource-pool-0.2.3.2-H8ME1Uq48cELXvsmcljq2I
    path-pieces-0.2.1-Bpsfe2mCPCaEayXevejNMW
    http-api-data-0.3.9-La58DF1PRky4R2af55hSiz
    aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX
    monad-logger-0.3.29-BNxohPHMKFFFoVBet7h5J8
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE
    template-haskell-2.13.0.0
    haskell-src-meta-0.8.0.3-CxBfmRqT01jLfpwXm4KU0I
    blaze-html-0.9.1.1-crQaAXRkXt2XDlbzXFON9
    blaze-markup-0.8.2.2-DLsNA1WKDw36RR9ku6FlST
    silently-1.2.5-FZMMMDRxyQgEpFUiscdY08 mtl-2.2.2
    fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS
    void-0.7.2-JAsenjnj1DBHDal2sW0JoW
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             conduit-1.3.0.3-6EkWr2AN7teFYGMPRMc0XT=49197c8ae925287d0624a2efaefca141
             resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q=b5273090c64c1efd0c4504885cc2bdef
             resource-pool-0.2.3.2-H8ME1Uq48cELXvsmcljq2I=2c1b1b2a84a776dc63a21d78666174b0
             path-pieces-0.2.1-Bpsfe2mCPCaEayXevejNMW=cd76e68cc8b98f29153c4833d11aa72a
             http-api-data-0.3.9-La58DF1PRky4R2af55hSiz=ad11c09c3e621daa86959c8003ebff93
             aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX=25adaf2f506e44c8d5bd8da34f9279d5
             monad-logger-0.3.29-BNxohPHMKFFFoVBet7h5J8=f339d3f7d2d6c50cd5ec1cc006a809d6
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre=264f905ec4c04eb05b5ff3d7321fae90
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE=4221e97be581adbf81c2554dcbaa8ab5
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             haskell-src-meta-0.8.0.3-CxBfmRqT01jLfpwXm4KU0I=f0d8e3117ecce07c9354fb2d80f0abe7
             blaze-html-0.9.1.1-crQaAXRkXt2XDlbzXFON9=c6e80aabf69818c42063522c698c33e8
             blaze-markup-0.8.2.2-DLsNA1WKDw36RR9ku6FlST=73c07c7dc173d95a5dd0d6c0058f8bb4
             silently-1.2.5-FZMMMDRxyQgEpFUiscdY08=d7e8b960393160a3da91c11a0dc6234c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e=a68d513cb967eb5123e3b68a7f96a4a8
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS=b3bd63f18add30d59629e9599623cc96
             void-0.7.2-JAsenjnj1DBHDal2sW0JoW=d1de746fbfbe471314dbcb65b5e13ec4
haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html: /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-2.8.2-90-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent
version: 2.8.2
id: persistent-2.8.2-82Rc70Hb1vyJFXNZccxdoo
key: persistent-2.8.2-82Rc70Hb1vyJFXNZccxdoo
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.
category: Database, Yesod
abi: 2580510583dfbfdb16e105f191f46e64
exposed: True
exposed-modules:
    Database.Persist Database.Persist.Class Database.Persist.Quasi
    Database.Persist.Sql Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.Types
hidden-modules: Database.Persist.Types.Base
                Database.Persist.Class.DeleteCascade
                Database.Persist.Class.PersistEntity
                Database.Persist.Class.PersistQuery
                Database.Persist.Class.PersistUnique
                Database.Persist.Class.PersistConfig
                Database.Persist.Class.PersistField
                Database.Persist.Class.PersistStore Database.Persist.Sql.Migration
                Database.Persist.Sql.Internal Database.Persist.Sql.Types
                Database.Persist.Sql.Raw Database.Persist.Sql.Raw.QQ
                Database.Persist.Sql.Run Database.Persist.Sql.Class
                Database.Persist.Sql.Orphan.PersistQuery
                Database.Persist.Sql.Orphan.PersistStore
                Database.Persist.Sql.Orphan.PersistUnique
import-dirs: /usr/lib/ghc-8.4.3/site-local/persistent-2.8.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/persistent-2.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/persistent-2.8.2
hs-libraries: HSpersistent-2.8.2-82Rc70Hb1vyJFXNZccxdoo
depends:
    base-4.11.1.0 bytestring-0.10.8.2 transformers-0.5.5.0 time-1.8.0.2
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh text-1.2.3.0
    containers-0.5.11.0 conduit-1.3.1-9IpzexlfScbIWLcvdqjLQq
    resourcet-1.2.2-Copf1KcSXrGBpDXg1KpYXt
    resource-pool-0.2.3.2-7Z0t1DzeWuSAk6n2fl6JOm
    path-pieces-0.2.1-Bpsfe2mCPCaEayXevejNMW
    http-api-data-0.3.10-GyS9xmrjmOC13sbwap3AvV
    aeson-1.4.1.0-FRlNztmBJkOGWbKGvmlaJP
    monad-logger-0.3.29-9KJKpEYRTHTIwBSCNLOhff
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    attoparsec-0.13.2.2-8we02vABEtHGk2BnvIppYV
    template-haskell-2.13.0.0
    haskell-src-meta-0.8.0.3-47WjIycE73JJssVVlrvoM2
    blaze-html-0.9.1.1-crQaAXRkXt2XDlbzXFON9
    blaze-markup-0.8.2.2-DLsNA1WKDw36RR9ku6FlST
    silently-1.2.5-FZMMMDRxyQgEpFUiscdY08 mtl-2.2.2
    fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS
    void-0.7.2-JAsenjnj1DBHDal2sW0JoW
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             conduit-1.3.1-9IpzexlfScbIWLcvdqjLQq=134efd8e0bc42d10a3cf4b45be2b4c10
             resourcet-1.2.2-Copf1KcSXrGBpDXg1KpYXt=3390a720ed062fc898bcd71558ce14a6
             resource-pool-0.2.3.2-7Z0t1DzeWuSAk6n2fl6JOm=5b745969d8cbcd47e186928fbec7203a
             path-pieces-0.2.1-Bpsfe2mCPCaEayXevejNMW=cd76e68cc8b98f29153c4833d11aa72a
             http-api-data-0.3.10-GyS9xmrjmOC13sbwap3AvV=ffbd7a9e1d9898e336fa3d13704e5908
             aeson-1.4.1.0-FRlNztmBJkOGWbKGvmlaJP=5da4d30660c7a0118522c660d6f5af43
             monad-logger-0.3.29-9KJKpEYRTHTIwBSCNLOhff=ad0d9a48c61166149717765c81bfe80c
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre=264f905ec4c04eb05b5ff3d7321fae90
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             attoparsec-0.13.2.2-8we02vABEtHGk2BnvIppYV=c37e9b7162f4a40359d5b1d46155434d
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             haskell-src-meta-0.8.0.3-47WjIycE73JJssVVlrvoM2=56f7df498f3a36ea7e9d8169460a5af3
             blaze-html-0.9.1.1-crQaAXRkXt2XDlbzXFON9=c6e80aabf69818c42063522c698c33e8
             blaze-markup-0.8.2.2-DLsNA1WKDw36RR9ku6FlST=73c07c7dc173d95a5dd0d6c0058f8bb4
             silently-1.2.5-FZMMMDRxyQgEpFUiscdY08=d7e8b960393160a3da91c11a0dc6234c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e=a68d513cb967eb5123e3b68a7f96a4a8
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS=b3bd63f18add30d59629e9599623cc96
             void-0.7.2-JAsenjnj1DBHDal2sW0JoW=d1de746fbfbe471314dbcb65b5e13ec4
haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html: /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
